<div align="center">
  <img src="https://raw.githubusercontent.com/ptweir/datura/main/images/datura_196.png"><br>
</div>

# Datura

A simple pure Python data visualization package.

[Documentation](https://datura.readthedocs.io)

[Code](https://github.com/ptweir/datura)
